@@ -1,7 +1,7 @@
 /*
  GNU Maverik - a system for managing display and interaction in 
                Virtual Environment applications.
- Copyright (C) 1999-2001 Advanced Interfaces Group
+ Copyright (C) 1999-2002 Advanced Interfaces Group
 
  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
@@ -772,11 +772,7 @@ int feature_vertices;
 #define CALLBACK
 #endif
 
-#ifdef __CYGWIN__
-typedef void (*MAVLIB_GLUCB)();
-#else
 typedef void (CALLBACK *MAVLIB_GLUCB)();
-#endif
 
 void CALLBACK my_begin(GLenum mode)
 {
